#
#         Yasuharu Okamoto, 2023.03
#
import numpy as np
import matplotlib.pyplot as plt
import pystan
import seaborn as sb
import pickle

s = input('Pop.1 = ').split()
pop1 = [int(v) for v in s]
s = input('Pop.2 = ').split()
pop2 = [int(v) for v in s]
print('Pop1 =', pop1)
print('Pop2 =', pop2)

sm = pystan.StanModel(file = 'xtable2by2.stan')
fit = sm.sampling(data = {'pop1':pop1, 'pop2':pop2}, n_jobs = 1)
print(fit)

sb.kdeplot(fit['p0'])
plt.title('Posterior Distribution of p0', fontsize = 16)
plt.savefig('Figp0.png')
plt.show()

sb.kdeplot(fit['p1'], label = 'p1')
sb.kdeplot(fit['p2'], label = 'p2')
plt.title('Posterior Distributions of p1 and p2', fontsize = 16)
plt.legend(fontsize = 16)
plt.savefig('Figp1p2.png')
plt.show()

ckL = [1 if v > 0 else 0 for v in fit['p1_p2']]
p_pos = sum(ckL) / len(ckL)
Q1, Med, Q3 = np.percentile(fit['p1_p2'], [25, 50, 75])
plt.title('Prop(p1-p2>0) = {0:.2f}'.format(p_pos) \
          + '\nQ1 = {0:.2f},  Med = {1:.2f},  Q3 = {2:.2f}'.
          format(Q1, Med, Q3), fontsize = 16)
sb.kdeplot(fit['p1_p2'], label = 'p1-p2')
plt.xlabel('p1 - p2', fontsize = 14)
plt.legend(fontsize = 14)
plt.tight_layout()
plt.savefig('FigDiffp1p2.png')
plt.show()
